@@ -215,6 +215,9 @@ command_t local_commands[] = {
   {"_-", (command_f )command_NOCRLF, "<string>", 
   "Same like __ but no CRLF at the end of line",
   COMMAND_FLAGS_NONE},
+  {"_X", (command_f )command_BIN_DATA, "<hex digits>", 
+  "Send hex digits as binary data",
+  COMMAND_FLAGS_NONE},
   {"_FLUSH", (command_f )command_FLUSH, "", 
   "Flush the cached lines, \n"
   "the AUTO Content-Length calculation will take place here",
@@ -301,10 +304,10 @@ command_t local_commands[] = {
   "Wait for processes <name>*\n",
   COMMAND_FLAGS_NONE},
 #endif
-  {"_SLEEP", (command_f )command_SLEEP, "<milisecond>", 
+  {"_SLEEP", (command_f )command_SLEEP, "<miliseconds>", 
    "Sleep for defined amount of time",
   COMMAND_FLAGS_NONE},
-  {"_TIMEOUT", (command_f )command_TIMEOUT, "<milisecond", 
+  {"_TIMEOUT", (command_f )command_TIMEOUT, "<miliseconds>", 
    "Set socket timeout of current socket",
   COMMAND_FLAGS_NONE},
   {"_SET", (command_f )command_SET, "<variable>=<value>", 
@@ -428,6 +431,9 @@ command_t local_commands[] = {
   {"_SSL_CONNECT", (command_f )command_SSL_CONNECT, "SSL|SSL2|SSL3|TLS1 [<cert-file> <key-file>]", 
   "Do a ssl connect on an already connected TCP socket",
   COMMAND_FLAGS_NONE},
+  {"_SSL_ACCEPT", (command_f )command_SSL_ACCEPT, "SSL|SSL2|SSL3|TLS1 [<cert-file> <key-file>]", 
+  "Do a ssl accept on an already accepted TCP socket",
+  COMMAND_FLAGS_NONE},
   {"_SSL_LEGACY", (command_f )command_SSL_LEGACY, "on|off", 
   "Turn on|off SSL legacy behavour for renegotiation for openssl libraries 0.9.8l and above",
   COMMAND_FLAGS_NONE},
@@ -494,6 +500,12 @@ command_t local_commands[] = {
   {"_LOCAL", (command_f )command_LOCAL, "<var>+", 
   "Define BLOCK local variables.",
   COMMAND_FLAGS_NONE},
+  {"_LOCK", (command_f )command_LOCK, "", 
+  "Draw the global lock",
+  COMMAND_FLAGS_NONE},
+  {"_UNLOCK", (command_f )command_UNLOCK, "", 
+  "Undraw the global lock",
+  COMMAND_FLAGS_NONE},
   {NULL, NULL, NULL, 
   NULL,
   COMMAND_FLAGS_NONE},
@@ -1763,6 +1775,7 @@ static void * APR_THREAD_FUNC worker_thread_listener(apr_thread_t * thread, void
 
   if (!nolistener) {
     if ((status = worker_listener_up(self, LISTENBACKLOG_DEFAULT)) != APR_SUCCESS) {
+      worker_log_error(self, "%s(%d)", my_status_str(self->pbody, status), status);
       goto error;
     }
   }
