@@ -28,5 +28,9 @@ void ssl_util_thread_setup(apr_pool_t * p);
 void ssl_rand_seed(void); 
 apr_status_t ssl_handshake(SSL *ssl, char **error, apr_pool_t *pool);
 apr_status_t ssl_accept(SSL *ssl, char **error, apr_pool_t *pool); 
+#ifndef OPENSSL_NO_ENGINE
+ENGINE *setup_engine(BIO *err, const char *engine, int debug); 
+#endif
+char *ssl_var_lookup_ssl_cert(apr_pool_t *p, X509 *xs, char *var); 
 
 #endif
