@@ -28,9 +28,11 @@ char *my_unescape(char *string, char **last);
 apr_table_t *my_table_deep_copy(apr_pool_t *p, apr_table_t *orig); 
 apr_table_t *my_table_swallow_copy(apr_pool_t *p, apr_table_t *orig); 
 char *my_status_str(apr_pool_t * p, apr_status_t rc); 
-char *my_replace_vars(apr_pool_t * p, char *line, apr_table_t * vars);
+char *my_replace_vars(apr_pool_t * p, char *line, apr_table_t * vars, 
+                      int lookup_env);
 void copyright(const char *progname); 
 const char *filename(apr_pool_t *pool, const char *path); 
 char x2c(const char *what); 
+void my_get_args(char *line, apr_table_t *params, apr_pool_t *pool); 
 
 #endif
