@@ -89,6 +89,7 @@ struct worker_s {
 #define FLAGS_AUTO_CLOSE     0x00000400
 #define FLAGS_AUTO_COOKIE    0x00000800
 #define FLAGS_IGNORE_BODY    0x00001000
+#define FLAGS_SKIP_FLUSH     0x00002000
   int flags;
   apr_proc_t proc;
   int cmd;
@@ -143,7 +144,7 @@ struct worker_s {
 #ifdef USE_SSL
   int is_ssl;
   SSL_CTX *ssl_ctx;
-  const SSL_METHOD *meth;
+  SSL_METHOD *meth;
   BIO *bio_out;
   BIO *bio_err;
   char *ssl_info;
@@ -287,6 +288,7 @@ apr_status_t command_MATCH(command_t * self, worker_t * worker, char *data);
 apr_status_t command_GREP(command_t * self, worker_t * worker, char *data);
 apr_status_t command_SET(command_t * self, worker_t * worker, char *data);
 apr_status_t command_DATA(command_t * self, worker_t * worker, char *data);
+apr_status_t command_BIN_DATA(command_t * self, worker_t * worker, char *data);
 apr_status_t command_FLUSH(command_t * self, worker_t * worker, char *data);
 apr_status_t command_CHUNK(command_t * self, worker_t * worker, char *data);
 apr_status_t command_EXEC(command_t * self, worker_t * worker, char *data);
@@ -327,6 +329,7 @@ apr_status_t command_BREAK(command_t *self, worker_t *worker, char *data);
 apr_status_t command_PRINT_HEX(command_t *self, worker_t *worker, char *data); 
 apr_status_t command_TIMER(command_t *self, worker_t *worker, char *data); 
 apr_status_t command_SSL_CONNECT(command_t *self, worker_t *worker, char *data);
+apr_status_t command_SSL_ACCEPT(command_t *self, worker_t *worker, char *data);
 apr_status_t command_SSL_LEGACY(command_t *self, worker_t *worker, char *data); 
 apr_status_t command_SSL_SECURE_RENEG_SUPPORTED(command_t *self, 
                                                 worker_t *worker, char *data);
@@ -349,6 +352,8 @@ apr_status_t command_USE(command_t *self, worker_t *worker, char *data);
 apr_status_t command_SSL_GET_SESSION(command_t *self, worker_t *worker, char *data); 
 apr_status_t command_SSL_SET_SESSION(command_t *self, worker_t *worker, char *data); 
 apr_status_t command_LOCAL(command_t *self, worker_t *worker, char *data); 
+apr_status_t command_LOCK(command_t *self, worker_t *worker, char *data); 
+apr_status_t command_UNLOCK(command_t *self, worker_t *worker, char *data); 
 
 /** helper */
 void worker_log(worker_t * self, int log_mode, char *fmt, ...); 
